genshi.template.plugin

Package genshi :: Package template :: Module plugin |

# Module plugin

Basic support for the template engine plugin API used by TurboGears and CherryPy/Buffet.

Classes
| ConfigurationError Exception raised when invalid plugin options are encountered.
| AbstractTemplateEnginePlugin Implementation of the plugin API.
| MarkupTemplateEnginePlugin Implementation of the plugin API for markup templates.
| TextTemplateEnginePlugin Implementation of the plugin API for text templates.